import React from "react";
import { Link, useNavigate } from "react-router-dom";
import { useAuth } from "../context/AuthContext";

const Navbar = () => {
  const navigate = useNavigate();
  const { isLoggedIn, logout, user } = useAuth();

  // ✅ 로그인 상태에 따라 메뉴 구성
  const menuItems = [
    { name: "home", path: "/" },
    { name: "about", path: "/about" },
    { name: "posts", path: "/posts" },
  ];

  if (isLoggedIn) {
    menuItems.push({ name: "tasks", path: "/tasks" });
    menuItems.push({ name: "ansible", path: "/ansible" });
  }

  return (
    <nav className="fixed w-full z-50 bg-white/90 backdrop-blur-md shadow-sm">
      <div className="container mx-auto px-4">
        <div className="flex justify-between items-center h-16">
          <Link to="/" className="text-2xl font-bold text-[#3B82F6]">
            Dev
          </Link>

          <div className="hidden md:flex items-center space-x-8">
            {menuItems.map((item) => (
              <Link
                key={item.name}
                to={item.path}
                className="text-gray-600 hover:text-[#D4AF37]"
              >
                {item.name.charAt(0).toUpperCase() + item.name.slice(1)}
              </Link>
            ))}

            {isLoggedIn ? (
              <>
                <Link
                  to="/profile"
                  className="bg-[#8b0000] text-white px-4 py-2 rounded hover:bg-gray-300"
                >
                  내 정보 {user?.grade && `(${user.grade})`}
                </Link>
                <button
                  onClick={() => {
                    logout();
                    navigate("/login");
                  }}
                  className="bg-gray-200 text-gray-700 px-4 py-2 rounded hover:bg-gray-300"
                >
                  로그아웃
                </button>
              </>
            ) : (
              <>
                <Link
                  to="/login"
                  className="bg-[#3B82F6] text-white px-4 py-2 rounded hover:bg-blue-700"
                >
                  로그인
                </Link>
                <Link
                  to="/register"
                  className="bg-gray-200 text-gray-700 px-4 py-2 rounded hover:bg-gray-300"
                >
                  회원가입
                </Link>
              </>
            )}
          </div>
        </div>
      </div>
    </nav>
  );
};

export default Navbar;
